@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.9 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.9 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigActions extends SyL_Config
@@ -54,9 +54,31 @@ class SyL_ConfigActions extends SyL_Config
     /**
      * ǥեȼ¹Խ
      * 
+     * @access private
      * @param int
      */
     var $default_priority = 5;
+    /**
+     * ǥեȥƥץ졼ȥ
+     * 
+     * @access private
+     * @param string
+     */
+    var $default_template_type = 'default';
+    /**
+     * ե륭å奭
+     * 
+     * @access private
+     * @param string
+     */
+    var $action_cache_key = '__syL_action_cache';
+    /**
+     * ե륭åǡ
+     * 
+     * @access private
+     * @var array
+     */
+    var $action_cache_value = array();
     /**
      * ǡ֥
      * 
@@ -64,13 +86,6 @@ class SyL_ConfigActions extends SyL_Config
      * @var object
      */
     var $dm = null;
-    /**
-     * ݡͥȥ᥽åɥ֥
-     * 
-     * @access private
-     * @var object
-     */
-    var $cm = null;
 
     /**
      * 󥹥ȥ饯
@@ -96,6 +111,69 @@ class SyL_ConfigActions extends SyL_Config
         $this->dm =& $controller->container->getComponent('datamanager');
     }
 
+    /**
+     * XMLեβϽ
+     *
+     * @access public
+     */
+    function parseXML()
+    {
+        if (SYL_WEBAPP_CACHE_DIR) {
+            // åѤ
+            $key = $this->dm->getActionDir() . $this->dm->getActionFile() . $this->dm->getActionName();
+            $cache =& SyL_Cache::getObject($key, 'fileupdate');
+            $cache->setCacheDir(SYL_WEBAPP_CACHE_DIR . '/actions');
+            $this->config = $cache->read($this->file_names);
+            if (!$this->config) {
+                parent::parseXML();
+                // åѥ᡼¸
+                $this->config[$this->action_cache_key] = $this->action_cache_value;
+                $cache->write($this->config);
+            } else {
+                // åѥ᡼
+                $this->action_cache_value = $this->config[$this->action_cache_key];
+            }
+            // åѥ᡼
+            unset($this->config[$this->action_cache_key]);
+        } else {
+            // åѤʤ
+            parent::parseXML();
+        }
+
+        $this->dm->setTemplateFile($this->action_cache_value['template']);
+        if (isset($this->action_cache_value['view_parameters'])) {
+            foreach ($this->action_cache_value['view_parameters'] as $name => $value) {
+                $this->dm->setViewParameter(strtolower($name), $value);
+            }
+        }
+
+        if (isset($this->action_cache_value['app_component'])) {
+            foreach ($this->action_cache_value['app_component'] as $name => $value) {
+                $this->dm->cm->addAppComponent($name, $value[0], $value[1]);
+            }
+        }
+    }
+
+/*
+
+key = $this->dm->getActionDir() . $this->dm->getActionFile() . $this->dm->getActionName() 
+ƥץ졼Ȼ
+ƥå
+$template
+$view_type
+$attribute['customizedViewFile'], 
+$attribute['customizedViewClass']
+$this->dm->cm->addAppComponent($component_name, '', $component_priority);
+$this->dm->cm->addAppComponent($component_name, $attribute['name'], $component_priority);
+
+פʤ
+XMLѡ
+å¸
+
+
+*/
+
+
     /**
      * XMLǡƼϥɥ᥽å
      * С饤
@@ -126,7 +204,6 @@ class SyL_ConfigActions extends SyL_Config
                 return;
             }
             if (isset($attribute['enable']) && ($attribute['enable'] === 'false')) {
-                $name = '';
                 return;
             }
 
@@ -148,21 +225,14 @@ class SyL_ConfigActions extends SyL_Config
                 $this->config[$name]['args'] = array();
 
                 // ǥեȥƥץ졼ȼ
-                $template = $attribute['defaultTemplate'];
+                $template = $attribute['template'];
                 for ($i=0; $i<count($matches); $i++) {
                     $template = str_replace("\${$i}", $matches[$i], $template);
                 }
-                $this->dm->setTemplateFile($template);
 
-                // ӥ塼饹
-                $view_type = isset($attribute['defaultView']) ? $attribute['defaultView'] : 'default';
-                $this->dm->setTemplateType($view_type);
-                // ޥӥ塼Ƚ
-                if (strtolower($view_type) == 'customize') {
-                    $this->dm->setCustomizedView($attribute['customizedViewFile'], $attribute['customizedViewClass']);
-                }
-            } else {
-                $name = '';
+                $this->action_cache_value['template']  = $template;
+                // ӥ塼ѥ᡼å
+                $this->action_cache_value['view_parameters'] = $attribute;
             }
             break;
 
@@ -194,7 +264,7 @@ class SyL_ConfigActions extends SyL_Config
                 $component_name = $attribute['name'];
                 $this->config[$component_name]['class']     = $attribute['class'];
                 $this->config[$component_name]['type']      = 'component';
-                $this->config[$component_name]['file']      = isset($attribute['file'])   ? $attribute['file']   : '';
+                $this->config[$component_name]['file']      = isset($attribute['file']) ? $attribute['file'] : '';
                 $this->config[$component_name]['reference'] = false;
                 // ¹Խ(1ʳᤤ)
                 $default_priority = $this->default_priority - 1;
@@ -208,7 +278,7 @@ class SyL_ConfigActions extends SyL_Config
                 $this->config[$component_name]['args'] = array();
 
                 // ץꥱ󥳥ݡͥ̾å
-                 $this->dm->cm->addAppComponent($component_name, '', $component_priority);
+                $this->action_cache_value['app_component'][$component_name] = array('', $component_priority);
                 break;
 
             default:
@@ -265,7 +335,7 @@ class SyL_ConfigActions extends SyL_Config
 
                 case '/actions/action/components/component/final':
                     // ץꥱ󥳥ݡͥ̾å
-                     $this->dm->cm->addAppComponent($component_name, $attribute['name'], $component_priority);
+                    $this->action_cache_value['app_component'][$component_name] = array($attribute['name'], $component_priority);
                     break;
                 }
             }
