@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActionscmd.php,v 1.4 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActionscmd.php,v 1.5 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActionscmd.php,v 1.4 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActionscmd.php,v 1.5 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigActionscmd extends SyL_Config
@@ -105,6 +105,27 @@ class SyL_ConfigActionscmd extends SyL_Config
         $this->cm         =& $controller->container->getComponent('componentmethod');
     }
 
+    /**
+     * XMLեβϽ
+     *
+     * @access public
+     */
+    function parseXML()
+    {
+        // 
+        $config = array();
+        foreach ($this->file_names as $file_name) {
+            parent::setFile($file_name);
+            parent::parseXML();
+            $config += $this->config;
+            // 
+            $this->config = array();
+        }
+
+        $this->config = $config;
+    }
+
+
     /**
      * XMLǡƼϥɥ᥽å
      * С饤
