@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.9 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.9 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigComponents extends SyL_Config
@@ -64,6 +64,29 @@ class SyL_ConfigComponents extends SyL_Config
         parent::SyL_Config($file_name);
     }
 
+    /**
+     * XMLեβϽ
+     *
+     * @access public
+     */
+    function parseXML()
+    {
+        if (SYL_WEBAPP_CACHE_DIR) {
+            // åѤ
+            $key = implode('', $this->file_names);
+            $cache =& SyL_Cache::getObject($key, 'fileupdate');
+            $cache->setCacheDir(SYL_WEBAPP_CACHE_DIR . '/components');
+            $this->config = $cache->read($this->file_names);
+            if (!$this->config) {
+                parent::parseXML();
+                $cache->write($this->config);
+            }
+        } else {
+            // åѤʤ
+            parent::parseXML();
+        }
+    }
+
     /**
      * XMLǡƼϥɥ᥽å
      * С饤
