@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.9 2007/01/03 11:17:37 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.10 2007/01/06 14:23:05 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -53,7 +53,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.9 2007/01/03 11:17:37 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.10 2007/01/06 14:23:05 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorWeb extends SyL_Error
@@ -95,6 +95,8 @@ class SyL_ErrorWeb extends SyL_Error
         $this->{$func_name}($error_string, $error_trace, $view_type);
         // 
         $this->logging();
+        // 顼᡼
+        $this->sendMail();
     }
 
     /**
