@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ComponentMethod.php,v 1.4 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ComponentMethod.php,v 1.5 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ComponentMethod.php,v 1.4 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ComponentMethod.php,v 1.5 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ComponentMethod
@@ -101,6 +101,19 @@ class SyL_ComponentMethod
      */
     function triggerApp($name)
     {
+        // Ͽå
+        $match = false;
+        foreach (array_keys($this->app_components) as $value) {
+            if (preg_match ('/^' . preg_quote($name, '/') . '/', $value)) {
+                $match = true;
+                break;
+            }
+        }
+
+        if (!$match) {
+            trigger_error("[SyL error] AppComponent not registered ({$name})", E_USER_ERROR);
+        }
+
         $component =& $this->getComponent($name);
         $args = func_get_args();
         array_shift($args);
@@ -117,11 +130,11 @@ class SyL_ComponentMethod
     function &getComponent($name)
     {
         if (!$this->controller->container->isComponent($name)) {
-            trigger_error("[SyL error] Filter or AppComponent is not undefined (name: {$name})", E_USER_ERROR);
+            trigger_error("[SyL error] Filter or AppComponent not registered ({$name})", E_USER_ERROR);
         }
         $component =& $this->controller->container->getComponent($name);
         if (!method_exists($component, $this->direct_method)) {
-            trigger_error("[SyL error] Filter or AppComponent method is not undefined (name: {$this->direct_method})", E_USER_ERROR);
+            trigger_error("[SyL error] Filter or AppComponent method undefined ({$this->direct_method})", E_USER_ERROR);
         }
         return $component;
     }
@@ -151,8 +164,8 @@ class SyL_ComponentMethod
         if (count($this->app_components) > 0) {
             // ¹ԽȤϵս˥
             arsort($this->app_components, SORT_NUMERIC);
-            foreach ($this->app_components as $name => $method) {
-                list($name, $method) = explode(':', $name, 2);
+            foreach (array_keys($this->app_components) as $value) {
+                list($name, $method) = explode(':', $value, 2);
                 if ($method != '') {
                    $component =& $this->controller->container->getComponent($name);
                    $component->{$method}();
