@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Config.php,v 1.9 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Config.php,v 1.10 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -36,6 +36,10 @@
  * XML饹
  */
 require_once SYL_INCLUDE_DIR . '/lib/SyL_XMLParserOperation.php';
+/**
+ * å奯饹
+ */
+require_once SYL_INCLUDE_DIR . '/lib/SyL_Cache.php';
 
 /** 
  * եɤ߹९饹
@@ -44,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_XMLParserOperation.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Config.php,v 1.9 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Config.php,v 1.10 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Config extends SyL_XMLParserOperation
@@ -56,6 +60,13 @@ class SyL_Config extends SyL_XMLParserOperation
      * @var string
      */
     var $event = '';
+    /**
+     * XMLե̾
+     * 
+     * @access private
+     * @var array
+     */
+    var $file_names = array();
     /**
      * ե
      * 
@@ -78,8 +89,7 @@ class SyL_Config extends SyL_XMLParserOperation
      */
     function SyL_Config($file_name)
     {
-        // ƥ饹Υ󥹥ȥ饯
-        parent::SyL_XMLParserOperation($file_name);
+        $this->file_names = explode(PATH_SEPARATOR, $file_name);
     }
 
     /**
@@ -124,6 +134,26 @@ class SyL_Config extends SyL_XMLParserOperation
         $this->event = $event;
     }
 
+    /**
+     * ʣXMLեβϤ
+     *
+     * @access public
+     */
+    function parseXML()
+    {
+        $config = array();
+        foreach ($this->file_names as $file_name) {
+            parent::setFile($file_name);
+            parent::parseXML();
+            if (is_array($this->config)) {
+                $config += $this->config;
+            }
+            // 
+            $this->config = array();
+        }
+        $this->config = $config;
+    }
+
     /**
      * XMLǡƼϥɥ᥽å
      * С饤
@@ -140,7 +170,7 @@ class SyL_Config extends SyL_XMLParserOperation
     /**
      * XMLͤ
      * 
-     * @return array XML
+     * @return array 
      */
     function getConfig()
     {
