@@ -27,13 +27,13 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.9 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
 /**
- * ƥեɤ߹ߥ饹
+ * եɤ߹९饹
  */
 require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
 
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.9 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Container
@@ -298,14 +298,9 @@ echo "</pre>";
     {
         $config = array();
         foreach ($config_type as $type => $file) {
-            $files = explode(PATH_SEPARATOR, $file);
-            foreach ($files as $f) {
-                if (!is_file($f)) {
-                    // ե뤬̵
-                    trigger_error("[SyL error] Config file not found (file name: {$f})", E_USER_ERROR);
-                }
-                $config += $this->getConfig($event, $type, $f);
-            }
+            $reader =& SyL_Config::getObject($type, $file, $this->getComponent(SYL_CONFIG_CONTROLLER_NAME), $event);
+            $reader->parseXML();
+            $config += $reader->getConfig();
         }
         return $config;
     }
@@ -319,6 +314,7 @@ echo "</pre>";
      * @param string ե
      * @return array ե
      */
+/*
     function getConfig($event, $type, $file)
     {
         if (file_exists($file)) {
@@ -329,6 +325,7 @@ echo "</pre>";
             return array();
         }
     }
+*/
 
     /**
      * ¹Խ̤ͥȤ˥Ȥ
