@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.10 2007/01/03 11:17:37 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.11 2007/01/06 14:23:05 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -74,7 +74,7 @@ define('SYL_CONFIG_CONTROLLER_NAME', 'controller');
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.10 2007/01/03 11:17:37 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.11 2007/01/06 14:23:05 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -375,29 +375,12 @@ class SyL_Controller
      */
     function getErrorMessage()
     {
-        return isset($this->error[1]) ? $this->error[1] : '';
-    }
-
-    /**
-     * 顼ե
-     * 
-     * @access public
-     * @return string 顼ե
-     */
-    function getErrorFile()
-    {
-        return isset($this->error[2]) ? $this->error[2] : '';
-    }
-
-    /**
-     * 顼Կ
-     * 
-     * @access public
-     * @return string 顼Կ
-     */
-    function getErrorLine()
-    {
-        return isset($this->error[3]) ? $this->error[3] : '';
+        $error_message  = '';
+        $error_message .= isset($this->error[1]) ? $this->error[1] : '';
+        if (isset($this->error[2]) && isset($this->error[3])) {
+            $error_message .= " ({$this->error[2]} on line {$this->error[3]})";
+        }
+        return $error_message;
     }
 
     /**
