@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.9 2007/01/03 11:17:37 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.10 2007/01/06 14:23:05 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.9 2007/01/03 11:17:37 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.10 2007/01/06 14:23:05 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Error
@@ -259,37 +259,97 @@ class SyL_Error
         return array_reverse($error_trace);
     }
 
+    /**
+     * 顼ȥ졼դ顼å
+     *
+     * @access public
+     * @return string 顼ȥ졼դ顼å
+     */
+    function getErrorMessageTrace()
+    {
+        $error_message = '[' . $this->getErrorType() . '] ' . implode($this->eof, $this->getErrorMessages()) . $this->eof;
+        foreach ($this->getTrace() as $value) {
+            $error_message .= "[file] "     . $value['file'] . " ";
+            $error_message .= "[line] "     . $value['line'] . " ";
+            $error_message .= "[function] " . $value['function'] . $this->eof;
+        }
+        return $error_message;
+    }
+
+
     /**
      * 󥰤¸
      *
      * @access public
-     * @param int 顼No
-     * @param string 顼å
      */
     function logging()
     {
-        $error_no = $this->controller->getErrorNo();
-        if ($error_no <= SYL_DEBUG) {
-            $log_string  = '[' . $this->getErrorType() . '] ' . implode($this->eof, $this->getErrorMessages()) . $this->eof;
-            foreach ($this->getTrace() as $value) {
-                $log_string .= "[file] "     . $value['file'] . " ";
-                $log_string .= "[line] "     . $value['line'] . " ";
-                $log_string .= "[function] " . $value['function'] . $this->eof;
+        // ȥ졼դ顼å
+        $error_message  = $this->getErrorMessageTrace();
+        // 顼٥˥¸
+        switch ($this->controller->getErrorNo()) {
+        case E_ERROR:
+        case E_USER_ERROR:
+            SyL_Loggers::error($error_message);
+            break;
+        case E_WARNING:
+        case E_USER_WARNING:
+            SyL_Loggers::warn($error_message);
+            break;
+        case E_NOTICE:
+        case E_USER_NOTICE:
+            SyL_Loggers::notice($error_message);
+            break;
+        }
+    }
+
+    /**
+     * 顼᡼
+     *
+     * @access public
+     */
+    function sendMail()
+    {
+        if (($this->controller->getErrorNo() <= SYL_DEBUG) && SYL_ERROR_MAIL && (SYL_ADMIN_MAIL_ADDRESS != '')) {
+            // ռ
+            $date = date('Y-m-d H:i:s');
+            // С̾
+            $server = isset($_SERVER['HTTP_HOST']) ? $_SERVER['HTTP_HOST'] : '';
+            if ($server == '') {
+                $server = isset($_SERVER['SERVER_NAME']) ? $_SERVER['SERVER_NAME'] : '';
+            }
+            if ($server == '') {
+                $server = trim(`hostname`);
             }
 
-            // 顼٥˥¸
-            switch ($error_no) {
-            case E_WARNING:
-            case E_USER_WARNING:
-                SyL_Loggers::warn($log_string);
-                break;
-            case E_NOTICE:
-            case E_USER_NOTICE:
-                SyL_Loggers::notice($log_string);
-                break;
-            default:
-                SyL_Loggers::error($log_string);
-                break;
+            // ȥ졼դ顼å
+            $error_message  = $this->getErrorMessageTrace();
+            // SyLΥС
+            $version = SYL_VERSION;
+
+            $error_mail_subject = "PHP Error occurred - {$server}";
+            $error_mail_body = <<< EOF
+SyL Framework Error info.
+----------------------------------------
+Date: {$date}
+Server: {$server}
+
+{$error_message}
+
+----------------------------------------
+SyL ver. {$version}
+EOF;
+
+            // 顼᡼¹
+            include_once SYL_INCLUDE_DIR . '/lib/SyL_Mail.php';
+            list($type) = explode(':', SYL_MAIL_TYPE, 2);
+            $mail =& SyL_Mail::getObject($type);
+            $mail->setSubject($error_mail_subject);
+            $mail->setFrom(SYL_ADMIN_MAIL_ADDRESS);
+            $mail->addTo(SYL_ADMIN_MAIL_ADDRESS);
+            $mail->setBody($error_mail_body);
+            if (!$mail->send()) {
+                SyL_Loggers::error($mail->getErrorMessage());
             }
         }
     }
