@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Filter.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Filter.php,v 1.9 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Filter.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Filter.php,v 1.9 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  **/
 class SyL_Filter
@@ -49,7 +49,7 @@ class SyL_Filter
      *
      * @access public
      */
-    function getValue()
+    function trigger()
     {
     }
 
