@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_MailDefault.php,v 1.7 2006/12/23 11:13:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_MailDefault.php,v 1.8 2007/01/06 14:23:05 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_MailDefault.php,v 1.7 2006/12/23 11:13:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_MailDefault.php,v 1.8 2007/01/06 14:23:05 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_MailDefault extends SyL_Mail
@@ -60,13 +60,11 @@ class SyL_MailDefault extends SyL_Mail
      * @access public
      * @param array ᡼°
      * @param bool ե饰
-     * @return OK: true, NG: false
      */
-    function init($attributes=array(), $all=false)
+    function init($attributes=array())
     {
         $attributes = array_change_key_case($attributes, CASE_LOWER);
-        parent::init($attributes, $all);
-        return true;
+        parent::init($attributes);
     }
 
     /**
@@ -77,19 +75,26 @@ class SyL_MailDefault extends SyL_Mail
      */
     function send()
     {
-        if (!parent::send()) {
+        // Fromɬ
+        if ($this->headers['MAIL_FROM'] == '') {
+            $this->error_message = "[SyL error] From Address not found";
+            return false;
+        }
+        // Toɬ
+        if (count($this->headers['To']) == 0) {
+            $this->error_message = "[SyL error] To Address not found";
             return false;
         }
 
-       // ꥿ѥΥå
-       if ($this->headers['MAIL_FROM'] != '') {
-           $additional_parameters = ' -f' . $this->headers['MAIL_FROM'];
-       } else {
-           $additional_parameters = null;
-       }
+        // ꥿ѥΥå
+        if ($this->headers['MAIL_FROM'] != '') {
+            $additional_parameters = ' -f' . $this->headers['MAIL_FROM'];
+        } else {
+            $additional_parameters = null;
+        }
 
-       // ᡼¹
-       if (!mail(null, $this->headers['Subject'], null, $this->getHeaderMessage($this->body), $additional_parameters)) {
+        // ᡼¹
+        if (!mail(null, $this->headers['Subject'], null, $this->getHeaderMessage($this->body), $additional_parameters)) {
             $this->error_message = "[SyL error] mail function execute error";
             return false;
         }
