@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_MailSmtp.php,v 1.7 2006/12/23 11:13:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_MailSmtp.php,v 1.8 2007/01/06 14:23:05 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -35,16 +35,14 @@
 /**
  * å³饹
  */
-require_once dirname(dirname(__FILE__)) . DIRECTORY_SEPARATOR . 'SyL_Socket.php';
+require_once dirname(dirname(__FILE__)) . '/SyL_Socket.php';
 
 /**
- * ᡼륵СΥۥ̾
+ * ᡼륵С
  */
-define('SYL_MAIL_SERVER_HOST', '');
-/**
- * ᡼륵СΥݡֹ
- */
-define('SYL_MAIL_SERVER_PORT', 25);
+if (!defined('SYL_MAIL_TYPE')) {
+    define('SYL_MAIL_TYPE', 'Smtp::');
+}
 
 /**
  * SMTP᡼饹
@@ -53,7 +51,7 @@ define('SYL_MAIL_SERVER_PORT', 25);
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_MailSmtp.php,v 1.7 2006/12/23 11:13:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_MailSmtp.php,v 1.8 2007/01/06 14:23:05 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_MailSmtp extends SyL_Mail
@@ -64,14 +62,21 @@ class SyL_MailSmtp extends SyL_Mail
      * @access private
      * @var string
      */
-    var $host = SYL_MAIL_SERVER_HOST;
+    var $host = '';
     /**
      * ᡼륵СΥݡ
      *
      * @access private
      * @var int
      */
-    var $port = SYL_MAIL_SERVER_PORT;
+    var $port = 25;
+    /**
+     * 
+     *
+     * @access private
+     * @var string
+     */
+    var $command_log = '';
     /**
      * åȥ饹
      *
@@ -87,6 +92,17 @@ class SyL_MailSmtp extends SyL_Mail
      */
     function SyL_MailSmtp()
     {
+        $tmp = explode(':', SYL_MAIL_TYPE, 3);
+        if (strtolower($tmp[0]) != 'smtp') {
+            $tmp[2] = $tmp[1];
+            $tmp[1] = $tmp[0];
+        }
+        if ($tmp[1] != '') {
+            $this->host = $tmp[1];
+        }
+        if (isset($tmp[2]) && is_numeric($tmp[2])) {
+            $this->port = $tmp[2];
+        }
         parent::SyL_Mail();
     }
 
@@ -118,39 +134,58 @@ class SyL_MailSmtp extends SyL_Mail
      * @access public
      * @param array ᡼°
      * @param bool ե饰
-     * @return OK: true, NG: false
      */
-    function init($attributes=array(), $all=false)
+    function init($attributes=array())
     {
         $attributes = array_change_key_case($attributes, CASE_LOWER);
-        parent::init($attributes, $all);
+        parent::init($attributes);
 
-        if ($all) {
-            // ۥȥå
-            if (isset($attributes['host'])) {
-                $this->host = $attributes['host'];
-            }
-            // ݡȥå
-            if (isset($attributes['port'])) {
-                $this->port = $attributes['port'];
-            }
-
-            // åȥ֥Ⱥ
-            $this->socket = new SyL_Socket($this->host, $this->port);
-            $this->socket->setDebugCallBackFunc(array(&$this, 'receiveMessage'));
-
-            if (!$this->socket->open()) {
-                $this->error_message = $this->socket->getLastError();
-                return false;
-            } else {
-                // ³å
-                $this->socket->receive();
-                // å
-                $this->socket->send('HELO ' . $this->host);
-                // å
-                $this->socket->receive();
-            }
+        // ۥȥå
+        if (isset($attributes['host'])) {
+            $this->host = $attributes['host'];
         }
+        // ݡȥå
+        if (isset($attributes['port'])) {
+            $this->port = $attributes['port'];
+        }
+    }
+
+    /**
+     * ᡼륵С³
+     *
+     * @access public
+     * @param string ᡼륵С
+     * @param int ݡֹ
+     * @return OK: true, NG: false
+     */
+    function connect($server='', $port=25)
+    {
+        if ($server != '') {
+            $this->setHost($server);
+        }
+        if ($port != '') {
+            $this->setPort($port);
+        }
+
+        if (is_object($this->socket)) {
+            $this->quit();
+        }
+        // åȥ֥Ⱥ
+        $this->socket = new SyL_Socket($this->host, $this->port);
+        $this->socket->setCommandCallBackFunc(array(&$this, 'receiveMessage'));
+
+        if (!$this->socket->open()) {
+            $this->error_message = $this->socket->getLastError();
+            return false;
+        } else {
+            // ³å
+            $this->socket->receive();
+            // å
+            $this->socket->send('HELO ' . $this->host);
+            // å
+            $this->socket->receive();
+        }
+
         return true;
     }
 
@@ -162,14 +197,22 @@ class SyL_MailSmtp extends SyL_Mail
      */
     function send()
     {
-        if (!parent::send()) {
+        // Fromɬ
+        if ($this->headers['MAIL_FROM'] == '') {
+            $this->error_message = "[SyL error] From Address not found";
+            return false;
+        }
+        // Toɬ
+        if (count($this->headers['To']) == 0) {
+            $this->error_message = "[SyL error] To Address not found";
             return false;
         }
 
         // åȺȽ
-        if (!is_object($this->socket) || !$this->socket->isSocket()) {
-            $this->error_message = "[SyL error] Socket not created";
-            return false;
+        $once = false;
+        if ($this->socket == null) {
+            $once = true;
+            $this->connect();
         }
 
         // ޥȯ ------------------------------------------------------------
@@ -187,6 +230,9 @@ class SyL_MailSmtp extends SyL_Mail
         }
 
         if ($this->isError()) {
+            if ($once) {
+                $this->quit();
+            }
             return false;
         }
 
@@ -204,6 +250,9 @@ class SyL_MailSmtp extends SyL_Mail
         $data .= '.';
 
         if ($this->isError()) {
+            if ($once) {
+                $this->quit();
+            }
             return false;
         }
 
@@ -215,6 +264,9 @@ class SyL_MailSmtp extends SyL_Mail
         $this->socket->receive();
 
         if ($this->isError()) {
+            if ($once) {
+                $this->quit();
+            }
             return false;
         }
 
@@ -223,8 +275,8 @@ class SyL_MailSmtp extends SyL_Mail
         // ꥻåȥå
         $this->socket->receive();
 
-        if ($this->isError()) {
-            return false;
+        if ($once) {
+            $this->quit();
         }
 
         // 
@@ -240,7 +292,7 @@ class SyL_MailSmtp extends SyL_Mail
      */
     function quit()
     {
-        if (is_object($this->socket) && $this->socket->isSocket()) {
+        if (is_object($this->socket)) {
             // λå
             $this->socket->send('QUIT');
             // λå
@@ -248,16 +300,20 @@ class SyL_MailSmtp extends SyL_Mail
             // åȤĤ
             $this->socket->close();
         }
+
+        $this->socket = null;
     }
 
     /**
-     * å
+     * SMTPޥɼå
      *
      * @access private
+     * @param string send or receive
      * @param string ޥɥå
      */
     function receiveMessage($type, $message)
     {
+        $this->command_log .= "[{$type}] {$message}\n";
         if ($type == 'receive') {
             if (preg_match('/^[4|5][0-9]{2}/', $message)) {
                 $this->error_message = "[SyL error] SMTP command error ($message)";
@@ -269,6 +325,17 @@ class SyL_MailSmtp extends SyL_Mail
             return true;
         }
     }
+
+    /**
+     * åȥޥɼ
+     *
+     * @access public
+     * @return string åȥޥɼ
+     */
+    function getCommandLog()
+    {
+        return $this->command_log;
+    }
 }
 
 ?>
