@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Mail.php,v 1.7 2006/12/23 11:13:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Mail.php,v 1.8 2007/01/06 14:23:05 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -35,20 +35,24 @@
 /**
  * ᡼ƤΥ󥳡ǥ
  */
-define( 'SYL_MAIL_ENCODE', 'JIS' );
+if (!defined('SYL_ENCODE_MAIL')) {
+    define('SYL_ENCODE_MAIL', 'ISO-2022-JP');
+}
 /**
  * 󥳡ǥ
  */
-define( 'SYL_INTERNAL_ENCODE', 'EUC-JP');
+if (!defined('SYL_ENCODE_INTERNAL')) {
+    define('SYL_ENCODE_INTERNAL', 'EUC-JP');
+}
 
 /**
- *  ᡼饹
+ * ᡼饹
  *
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Mail.php,v 1.7 2006/12/23 11:13:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Mail.php,v 1.8 2007/01/06 14:23:05 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Mail
@@ -115,14 +119,14 @@ class SyL_Mail
      * @access protected
      * @var string
      */
-    var $mail_encode = SYL_MAIL_ENCODE;
+    var $mail_encode = SYL_ENCODE_MAIL;
     /**
      * ѥ᡼Υ󥳡
      * 
      * @access protected
      * @var string
      */
-    var $parameter_encode = SYL_INTERNAL_ENCODE;
+    var $internal_encode = SYL_ENCODE_INTERNAL;
     /**
      * 顼å
      * 
@@ -142,7 +146,9 @@ class SyL_Mail
         $this->headers_etc['Mime-version'] = '1.0';
         $this->headers_etc['Content-type'] = 'text/plain; charset="iso-2022-jp"';
         $this->headers_etc['Content-transfer-encoding'] = '7bit';
-        $this->headers_etc['X-Mailer']     = $this->x_mailer;
+        if ($this->x_mailer != '') {
+            $this->headers_etc['X-Mailer'] = $this->x_mailer;
+        }
 
         $this->init();
     }
@@ -160,7 +166,7 @@ class SyL_Mail
     function &getObject($type='Default')
     {
         $class_name = 'SyL_Mail' . ucfirst($type);
-        include_once dirname(__FILE__) . DIRECTORY_SEPARATOR . 'Mail' . DIRECTORY_SEPARATOR . $class_name . '.php';
+        include_once dirname(__FILE__) . '/Mail/' . $class_name . '.php';
         $obj = new $class_name();
         return $obj;
     }
@@ -281,7 +287,7 @@ class SyL_Mail
      */
     function setParameterEncode($encode)
     {
-        $this->parameter_encode = $encode;
+        $this->internal_encode = $encode;
     }
 
     /**
@@ -305,7 +311,7 @@ class SyL_Mail
      */
     function convertEncoding($parameter, $mime_encode=false)
     {
-        $parameter = mb_convert_encoding($parameter, $this->mail_encode, $this->parameter_encode);
+        $parameter = mb_convert_encoding($parameter, $this->mail_encode, $this->internal_encode);
         if ($mime_encode) {
             $parameter = mb_encode_mimeheader($parameter, $this->mail_encode);
         }
@@ -397,9 +403,8 @@ class SyL_Mail
      * @access public
      * @param array ᡼°
      * @param bool ե饰
-     * @return OK: true, NG: false
      */
-    function init($attributes=array(), $all=false)
+    function init($attributes=array())
     {
         $attributes = array_change_key_case($attributes, CASE_LOWER);
 
@@ -506,17 +511,6 @@ class SyL_Mail
      */
     function send()
     {
-        // Fromɬ
-        if ($this->headers['MAIL_FROM'] == '') {
-            $this->error_message = "[SyL error] From Address not found";
-            return false;
-        }
-        // Toɬ
-        if (count($this->headers['To']) == 0) {
-            $this->error_message = "[SyL error] To Address not found";
-            return false;
-        }
-        return true;
     }
 
     /**
