@@ -27,13 +27,11 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Socket.php,v 1.7 2006/12/23 11:13:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Socket.php,v 1.8 2007/01/06 14:23:05 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
-define('SYL_DEBUG', false);
-
 /**
  *  åȥ饹
  *
@@ -41,7 +39,7 @@ define('SYL_DEBUG', false);
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Socket.php,v 1.7 2006/12/23 11:13:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Socket.php,v 1.8 2007/01/06 14:23:05 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Socket
@@ -116,7 +114,7 @@ class SyL_Socket
      * @access public
      * @param mixed ǥХåʸ᥽å
      */
-    function setDebugCallBackFunc($debug_callback_func)
+    function setCommandCallBackFunc($debug_callback_func)
     {
         $this->debug_callback_func =& $debug_callback_func;
     }
