@@ -6,7 +6,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: C_CreateProject.php,v 1.3 2006/12/23 11:14:31 seasonstream Exp $
+ * @version   CVS: $Id: C_CreateProject.php,v 1.4 2007/01/06 14:23:05 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class C_CreateProject
@@ -33,8 +33,11 @@ class C_CreateProject
           'var'       => 0755,
           'var/logs'  => 0777,
           'var/cache' => 0777,
-          'var/skel-templates'  => 0777,
-          'var/smarty' => 0777
+          'var/skel-templates' => 0755,
+          'var/smarty'         => 0755,
+          'var/smarty/cache'   => 0777,
+          'var/smarty/configs' => 0777,
+          'var/smarty/templates_c' => 0777
         );
 
         foreach ($dirs as $dir => $mode) {
